EDuke32 Changelog Unofficial archive

What changed in EDuke32, build by build

2,117 builds · 8,866 commits · 25 authors · October 2009 – August 2026

Commits per year

Showing 2011 · select it again to see every year
SVN era · r1519 – r8798 Git era · voidpoint.io, from april 2020
Filters · 2 active

Showing 1 build · 1 commit

Export CSV
Display options
Commit details:

September 2011 1 build · 1 commit

Build 2044

25 Sep 2011 · 3 commits · 1 author SVN
Open build
  • VPX

    in 3 planes -> packed format conversion code, group together the

    Helixhorned r2042 25 Sep, 08:11
    Show details

    three individual loops and compile the enclosing function at -O3 (-O1 for debugging builds). Now, the time for this conversion ranges from 7 to 18 ms per frame across various tested machines, a clear improvement.

Open the build to see all 3 commits